#### Please select the sections that you would like to print

Select All
Case Information
Party
Causes
Events and Hearings
Print

# Case Information

MGCV17-11099 | TD Bank USA, N.A. vs Henry C. Monteith

Case Number
MGCV17-11099

Court
Magistrate Civil

File Date
08/14/2017

Case Type
General Civil Other

Case Status
Closed

# Party

Plaintiff
TD Bank USA, N.A.

Active Attorneys

Lead Attorney
Woolaston, Dorian

Retained

Defendant
Monteith, Henry C.

Active Attorneys

Pro Se

# Cause of Action

File Date | Cause of Action | Type | Filed By | Filed Against
--- | --- | --- | --- | ---
08/14/2017 | Account | Action | 767 | 767

# Events and Hearings

- 08/14/2017 Complaint - Filed

- 08/14/2017 Cause Of Action

  Action
  Account

  File Date
  08/14/2017

- 08/16/2017 Service - Sent To Sheriff's Department

- 08/16/2017 Summons

  Requested By
  TD Bank USA, N.A.

  Served
  08/24/2017

- 08/24/2017 Personal Service

  Comment
  CPL G WILLIAMS/724

- 12/08/2017 Consent Judgment Filed

- 12/12/2017 Consent - Judgment